#!/bin/sh

# site_sign.sh
# Website Signature Verifier
# by Javantea aka. Joel R. Voss
# Send an e-mail when AltSci.com has a cryptographic error.
# This works directly with gen_index_sig1.sh

# TESTDIR is the directory to do the testing. You need write access.
TESTDIR=/home/jvoss/site_sign

# FILE is the remote file that you wish to test.
FILE=index.html

# SITE is the server that you wish to test.
SITE=http://www.altsci.com

# KEY is the Key ID that you wish to ensure in Level 2.
KEY=1954FED2

# EMAIL is the address that you wish to send an e-mail to when a compromise has 
# been found.
EMAIL=jvoss@altsci.com

if ! [ -d $TESTDIR ]; then
	echo "Creating directory. This will result in failure of Level 3."
	mkdir $TESTDIR
fi

cd $TESTDIR

if [ -a $FILE ] || [ -a $FILE.asc ]; then
	echo "Bad deal: test directory has index file in it. moving it to .bak."
	mv $FILE $FILE.bak
	mv $FILE.asc $FILE.asc.bak
fi

# The first test checks to see whether the file has been signed.
# It does not currently check whether it is actually legit.

curl $SITE/$FILE -o $FILE
curl $SITE/$FILE.asc -o $FILE.asc

if gpg --verify $FILE.asc; then
	echo "Passed Level 1 (sign)"
else
	echo "Failed Level 1 (sign)"
	gpg --verify $FILE.asc 2>&1| mail -s "Server Compromise (sign) `date`" $EMAIL
fi

# The second test is more rigorous.
# It tests whether the key was signed with the correct key id.

DATA=`gpg --verify $FILE.asc 2>&1 | grep "using DSA key ID $KEY\$"`
if [ "$DATA" != "" ]; then
	echo $DATA
	echo "Passed Level 2 (key ID)"
else
	echo "Failed Level 2 (key ID)"
	gpg --verify $FILE.asc 2>&1| mail -s "Server Compromise (key ID) `date`" $EMAIL
fi

# The third test is even more rigorous.
# It tests against local copy to check if the server has been changed without updating the local signature.

if ! [ -a $FILE.asc.local ]; then
	echo "Failed to find Level 3 Local Signature."
	# Optionally, we could get the local signature from the remote, but that would allow a possible compromise.
	#cp $FILE.asc $FILE.asc.local
	echo $PWD/$FILE.asc.local | mail -s "Server Compromise (local sign) `date`" $EMAIL
	# Do not test Level 3.
	exit
fi

cp $FILE.asc.local $FILE.asc

if gpg --verify $FILE.asc; then
	echo "Passed Level 3 (local signature)"
else
	echo "Failed Level 3 (local signature)"
	gpg --verify $FILE.asc 2>&1| mail -s "Server Compromise (local sign) `date`" $EMAIL
fi


rm $FILE $FILE.asc

